package com.zolive33.zomaterialcomponents;

import android.content.Context;
import android.text.Editable;
import android.text.TextWatcher;
import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.View;
import android.view.inputmethod.InputMethodManager;
import android.widget.AdapterView;
import android.widget.LinearLayout;

import com.google.android.material.textfield.TextInputEditText;
import com.google.android.material.textfield.TextInputLayout;
import com.zolive33.zomaterialcomponents.toolbox.Utils;

import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.keywords.Common.DesignerCustomView;
import anywheresoftware.b4a.objects.LabelWrapper;
import anywheresoftware.b4a.objects.PanelWrapper;
import anywheresoftware.b4a.objects.ViewWrapper;
import anywheresoftware.b4a.objects.collections.Map;

@SuppressWarnings("unused")

@BA.ActivityObject

@BA.Events(values={
        "EnterPressed",
        "TextChanged (Old As String, New As String)",
        "FocusChanged (HasFocus As Boolean)"
})

@BA.DesignerProperties(values = {
        @BA.Property(key="Hint", displayName="Hint Text", fieldType="String", defaultValue="Hint"),
        @BA.Property(key="BoxCornerRadius", displayName="Box corner radius (dip)", fieldType="Int", defaultValue="-1", description="Set box corner radius (default -1)")
})

@BA.ShortName("TextInputEditText")

public class TextInputEditTextWrapper extends ViewWrapper<TextInputEditText> implements DesignerCustomView {

    private BA mBa;
    private String mEventName;
    private anywheresoftware.b4a.objects.collections.Map mProps;
    private TextInputLayout mTextInputLayout;

    @Override
    @BA.Hide
    public void _initialize(final BA ba, Object activityClass, String EventName) {
        this.mEventName = EventName.toLowerCase(BA.cul);
        this.mBa = ba;
    }


    private void initEvents() {

        if (mBa.subExists(mEventName + "_enterpressed")) {
            this.getObject().setOnEditorActionListener(new android.widget.TextView.OnEditorActionListener() {
                public boolean onEditorAction(android.widget.TextView v, int actionId, KeyEvent event) {
                    mBa.raiseEvent(mBa.context, mEventName + "_enterpressed");
                    return false;
                }
            });
        }

        if (mBa.subExists(mEventName + "_focuschanged")) {
            this.getObject().setOnFocusChangeListener(new View.OnFocusChangeListener() {
                public void onFocusChange(View v, boolean hasFocus) {
                    BA.Log("focusChanged");
                    mBa.raiseEvent(mBa.context, mEventName + "_focuschanged", hasFocus);
                }
            });
        }

        if (mBa.subExists(mEventName + "_textchanged")) {
            TextWatcher watcher = new TextWatcher() {
                private CharSequence old;

                public void afterTextChanged(Editable s) {
                    mBa.raiseEvent2(mBa.context, false, mEventName + "_textchanged", true, this.old, s.toString());
                }

                public void beforeTextChanged(CharSequence s, int start, int count, int after) {
                    this.old = s.toString();
                }

                public void onTextChanged(CharSequence s, int start, int before, int count) {}
            };
            this.getObject().addTextChangedListener(watcher);
        }

    }

    @Override
    public void DesignerCreateView(PanelWrapper base, LabelWrapper lw, anywheresoftware.b4a.objects.collections.Map props) {

        mProps = props;

        View view = LayoutInflater.from(mBa.context).inflate(R.layout.material_edit_text, null);
        mTextInputLayout =  view.findViewById(R.id.IDTextInputLayout);
        setObject((TextInputEditText) view.findViewById(R.id.IDTextInputEditText));

        initEvents();

        //Set corner radius
        if ((Integer)props.Get("BoxCornerRadius") > -1) {
            setBoxCornerRadius(((Integer) props.Get("BoxCornerRadius")).floatValue());
        }

        base.AddView(view, 0, 0, base.getWidth(), base.getHeight());

        //set hint properties
        mTextInputLayout.setHint((String)props.Get("Hint"));
    }

    private void setBoxCornerRadius (Float radius) {
        Float BoxCornerRadius = Utils.convertDpToPx(mBa.context, radius);
        mTextInputLayout.setBoxCornerRadii(BoxCornerRadius,
                BoxCornerRadius,
                BoxCornerRadius,
                BoxCornerRadius);
    }

}
